==> marketplace-constants-0.1.5.tar.gz: marketplace-constants-0.1.5/mpconstants/regions/mn.py <==
REGIONS = {u'ad': u'\u0410\u043d\u0434\u043e\u0440\u0440\u0430',
 u'ae': u'U.A.E.',
 u'af': u'\u0410\u0444\u0433\u0430\u043d\u0438\u0441\u0442\u0430\u043d',
 u'ag': u'Antigua and Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Netherlands Antilles',
 u'ao': u'\u0410\u043d\u0433\u043e\u043b',
 u'aq': u'Antarctica',
 u'ar': u'\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u044c',
 u'as': u'American Samoa',
 u'at': u'\u0410\u0432\u0441\u0442\u0440\u0438',
 u'au': u'\u0410\u0432\u0441\u0442\u0440\u0430\u043b\u044c',
 u'aw': u'Aruba',
 u'ax': u'\\u00c5land Islands',
 u'az': u'\u0410\u0437\u0435\u0440\u0431\u0435\u0436\u0430\u043d',
 u'ba': u'Bosnia and Herzegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'\u0411\u0435\u043b\u0433\u0438',
 u'bf': u'Burkina Faso',
 u'bg': u'\u0411\u043e\u043b\u0433\u0430\u0440',
 u'bh': u'\u0411\u0430\u0445\u0440\u044d\u0439\u043d',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\\u00e9lemy',
 u'bm': u'Bermuda',
 u'bn': u'\u0411\u0440\u0443\u043d\u044d\u0439 \u0414\u0440\u0430\u0441\u0443\u043b\u0430\u043c',
 u'bo': u'\u0411\u043e\u043b\u0438\u0438\u0432',
 u'br': u'\u0411\u0440\u0430\u0437\u0438\u043b\u044c',
 u'bs': u'\u0411\u0430\u0445\u0430\u043c\u0430',
 u'bt': u'\u0411\u0443\u0442\u0430\u043d',
 u'bv': u'Bouvet Island',
 u'bw': u'\u0411\u043e\u0442\u0441\u0432\u0430\u043d\u0430',
 u'by': u'\u0411\u0435\u043b\u0430\u0440\u0443\u0441',
 u'bz': u'\u0411\u0435\u043b\u0438\u0437',
 u'ca': u'\u041a\u0430\u043d\u0430\u0434',
 u'cc': u'Cocos (Keeling) Islands',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Central African Republic',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'\u0428\u0432\u0435\u0439\u0446\u0430\u0440\u044c',
 u'ci': u'Ivory Coast',
 u'ck': u'Cook Islands',
 u'cl': u'\u0427\u0438\u043b',
 u'cm': u'\u041a\u0430\u043c\u0435\u0440\u0443\u043d',
 u'cn': u'\u0425\u044f\u0442\u0430\u0434',
 u'co': u'\u041a\u043e\u043b\u0443\u043c\u0431',
 u'cr': u'\u041a\u043e\u0441\u0442\u0430 \u0440\u0438\u043a\u0430',
 u'cu': u'\u041a\u0443\u0431\u0430',
 u'cv': u'Cape Verde',
 u'cx': u'Christmas Island',
 u'cy': u'Cyprus',
 u'cz': u'\u0427\u0435\u0445',
 u'de': u'\u0413\u0435\u0440\u043c\u0430\u043d',
 u'dj': u'Djibouti',
 u'dk': u'\u0414\u0430\u043d\u0438',
 u'dm': u'Dominica',
 u'do': u'\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d\u044b \u043d\u044d\u0433\u0434\u0441\u044d\u043d \u0430\u0440\u0434',
 u'dz': u'\u0410\u043b\u0436\u0435\u0440',
 u'ec': u'\u042d\u043a\u0443\u0430\u0434\u043e\u0440',
 u'ee': u'Estonia',
 u'eg': u'\u0415\u0433\u0438\u043f\u0442',
 u'eh': u'Western Sahara',
 u'er': u'Eritrea',
 u'es': u'\u0418\u0441\u043f\u0430\u043d',
 u'et': u'Ethiopia',
 u'fi': u'\u0424\u0438\u043d\u043b\u0430\u043d\u0434',
 u'fj': u'Fiji',
 u'fk': u'Falkland Islands (Malvinas)',
 u'fm': u'Micronesia',
 u'fo': u'Faroe Islands',
 u'fr': u'\u0424\u0440\u0430\u043d\u0446',
 u'ga': u'Gabon',
 u'gb': u'\u0410\u043d\u0433\u043b\u0438',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'French Guiana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Greenland',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Equatorial Guinea',
 u'gr': u'\u0413\u0440\u0435\u043a',
 u'gs': u'South Georgia and the South Sandwich Islands',
 u'gt': u'\u0413\u0443\u0430\u0442\u044d\u043c\u044d\u043b\u0430',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'\u0413\u043e\u043d\u0433 \u041a\u043e\u043d\u0433',
 u'hm': u'Heard Island and McDonald Islands',
 u'hn': u'\u0413\u043e\u043d\u0434\u0443\u0440',
 u'hr': u'\u041a\u0440\u043e\u0430\u0446\u0438',
 u'ht': u'Haiti',
 u'hu': u'\u0423\u043d\u0433\u0430\u0440',
 u'id': u'Indonesia',
 u'ie': u'\u0418\u0440\u043b\u0430\u043d\u0434',
 u'il': u'\u0418\u0437\u0440\u0430\u0439\u043b\u044c',
 u'im': u'Isle of Man',
 u'in': u'\u042d\u043d\u044d\u0442\u0445\u044d\u0433',
 u'io': u'British Indian Ocean Territory',
 u'iq': u'\u0418\u0440\u0430\u043a',
 u'ir': u'\u0418\u0440\u0430\u043d',
 u'is': u'Iceland',
 u'it': u'\u0418\u0442\u0430\u043b',
 u'je': u'Jersey',
 u'jm': u'\u0416\u0430\u043c\u0430\u0439\u043a',
 u'jo': u'\u0401\u0440\u0434\u0430\u043d',
 u'jp': u'\u042f\u043f\u043e\u043d',
 u'ke': u'Kenya',
 u'kg': u'Kyrgyzstan',
 u'kh': u'Cambodia',
 u'ki': u'Kiribati',
 u'km': u'Comoros',
 u'kn': u'Saint Kitts and Nevis',
 u'kp': u'\u0425\u043e\u0439\u0434 \u0441\u043e\u043b\u043e\u043d\u0433\u043e\u0441',
 u'kr': u'\u04e8\u043c\u043d\u04e9\u0434 \u0421\u043e\u043b\u043e\u043d\u0433\u043e\u0441',
 u'kw': u'\u041a\u0443\u0432\u044d\u0439\u0442',
 u'ky': u'Cayman Islands',
 u'kz': u'Kazakhstan',
 u'la': u'Laos',
 u'lb': u'\u041b\u044d\u0431\u0430\u043d',
 u'lc': u'Saint Lucia',
 u'li': u'\u041b\u0438\u0445\u0442\u044d\u043d\u0448\u0442\u0430\u0439\u043d',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'\u041b\u0438\u0442\u0430\u0443\u0430\u043d',
 u'lu': u'\u041b\u0443\u043a\u0441\u044d\u043d\u0431\u0443\u0440\u0433',
 u'lv': u'Latvia',
 u'ly': u'\u041b\u0438\u0431\u0438\u0430',
 u'ma': u'\u041c\u043e\u0440\u0440\u043e\u043a',
 u'mc': u'\u041c\u043e\u043d\u0430\u043a',
 u'md': u'Moldova',
 u'me': u'\u041c\u043e\u043d\u0442\u044d\u043d\u0435\u0433\u0440\u043e',
 u'mf': u'\u0421\u044d\u0439\u043d \u041c\u0430\u0440\u0442\u0438\u043d',
 u'mg': u'Madagascar',
 u'mh': u'Marshall Islands',
 u'mk': u'Macedonia, F.Y.R. of',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'\u041c\u043e\u043d\u0433\u043e\u043b',
 u'mo': u'\u041c\u0430\u043a\u0430\u043e',
 u'mp': u'Northern Mariana Islands',
 u'mq': u'Martinique',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Maldives',
 u'mw': u'Malawi',
 u'mx': u'\u041c\u0435\u043a\u0441\u0438\u043e',
 u'my': u'\u041c\u0430\u043b\u0430\u0439\u0437',
 u'mz': u'Mozambique',
 u'na': u'Namibia',
 u'nc': u'New Caledonia',
 u'ne': u'Niger',
 u'nf': u'Norfolk Island',
 u'ng': u'Nigeria',
 u'ni': u'\u041d\u0438\u043a\u0430\u0440\u0430\u0433\u0443\u0430\u0433',
 u'nl': u'\u0413\u043e\u043b\u043b\u0430\u043d\u0434',
 u'no': u'\u041d\u043e\u0440\u0432\u0435\u0433',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'\u0428\u0438\u043d\u044d \u0437\u0435\u043b\u0430\u043d\u0434',
 u'om': u'\u041e\u043c\u0430\u043d',
 u'pa': u'\u041f\u0430\u043d\u0430\u043c',
 u'pe': u'\u041f\u0435\u0440\u0443',
 u'pf': u'French Polynesia',
 u'pg': u'Papua New Guinea',
 u'ph': u'\u0424\u0438\u043b\u0438\u043f\u0438\u043d',
 u'pk': u'\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u043d',
 u'pl': u'\u041f\u043e\u043b\u044c\u0448',
 u'pm': u'Saint Pierre and Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'\u041f\u0443\u044d\u0440\u0442\u043e \u0440\u0438\u043a\u043e',
 u'ps': u'Occupied Palestinian Territory',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'\u041f\u0430\u0440\u0430\u0433\u0443\u0430\u0439',
 u'qa': u'\u041a\u0430\u0442\u0430\u0440',
 u're': u'Reunion',
 u'ro': u'\u0420\u0443\u043c\u0438\u043d',
 u'rs': u'\u0421\u0435\u0440\u0431',
 u'ru': u'\u041e\u0440\u043e\u0441',
 u'rw': u'Rwanda',
 u'sa': u'\u0421\u0430\u0443\u0434\u044b\u043d \u0410\u0440\u0430\u0431',
 u'sb': u'\u0421\u043e\u043b\u043e\u043c\u043e\u043d \u0430\u0440\u0430\u043b',
 u'sc': u'Seychelles',
 u'sd': u'\u0421\u0443\u0434\u0430\u043d',
 u'se': u'\u0428\u0432\u0435\u0434\u044c',
 u'sg': u'\u0421\u0438\u043d\u0433\u0430\u043f\u0443\u0440',
 u'sh': u'Saint Helena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard and Jan Mayen',
 u'sk': u'\u0421\u043b\u043e\u0432\u0430\u043a',
 u'sl': u'Sierra Leone',
 u'sm': u'\u0421\u0430\u043d \u041c\u0430\u0440\u0438\u043d\u043e',
 u'sn': u'\u0421\u0435\u043d\u0435\u0433\u0430\u043b',
 u'so': u'Somalia',
 u'sr': u'Suriname',
 u'st': u'Sao Tome and Principe',
 u'sv': u'\u042d\u043b \u0441\u0430\u043b\u044c\u0432\u0430\u0434\u043e\u0440',
 u'sy': u'\u0421\u0438\u0440\u044c',
 u'sz': u'Swaziland',
 u'tc': u'Turks and Caicos Islands',
 u'td': u'Chad',
 u'tf': u'French Southern Territories',
 u'tg': u'Togo',
 u'th': u'\u0422\u0430\u0439\u043b\u0430\u043d\u0434',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'\u0422\u0443\u043d\u0435\u0441',
 u'to': u'Tonga',
 u'tr': u'\u0422\u0443\u0440\u043a',
 u'tt': u'\u0422\u0440\u0438\u043d\u0438\u0434\u0430\u0434',
 u'tv': u'Tuvalu',
 u'tw': u'\u0422\u0430\u0439\u0432\u0430\u043d\u044c',
 u'tz': u'Tanzania',
 u'ua': u'\u0423\u043a\u0440\u0430\u0439\u043d',
 u'ug': u'Uganda',
 u'um': u'United States Minor Outlying Islands',
 u'us': u'\u0410\u043c\u0435\u0440\u0438\u043a',
 u'uy': u'\u0423\u0440\u0443\u0433\u0443\u0430\u0439',
 u'uz': u'Uzbekistan',
 u'va': u'Vatican City',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'\u0412\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u044c',
 u'vg': u'British Virgin Islands',
 u'vi': u'U.S. Virgin Islands',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis and Futuna',
 u'ws': u'Samoa',
 u'ye': u'\u0415\u043c\u0435\u043d',
 u'yt': u'Mayotte',
 u'za': u'\u04e8\u043c\u043d\u04e9\u0434 \u0430\u0444\u0440\u0438\u043a',
 u'zm': u'Zambia',
 u'zw': u'\u0417\u0438\u043c\u0431\u0430\u0431'}

==> marketplace-constants-0.4.0.tar.gz: marketplace-constants-0.4.0/mpconstants/regions/mn.py <==
REGIONS = {u'ad': u'\u0410\u043d\u0434\u043e\u0440\u0440\u0430',
 u'ae': u'U.A.E.',
 u'af': u'\u0410\u0444\u0433\u0430\u043d\u0438\u0441\u0442\u0430\u043d',
 u'ag': u'Antigua and Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Netherlands Antilles',
 u'ao': u'\u0410\u043d\u0433\u043e\u043b',
 u'aq': u'Antarctica',
 u'ar': u'\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u044c',
 u'as': u'American Samoa',
 u'at': u'\u0410\u0432\u0441\u0442\u0440\u0438',
 u'au': u'\u0410\u0432\u0441\u0442\u0440\u0430\u043b\u044c',
 u'aw': u'Aruba',
 u'ax': u'\xc5land Islands',
 u'az': u'\u0410\u0437\u0435\u0440\u0431\u0435\u0436\u0430\u043d',
 u'ba': u'Bosnia and Herzegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'\u0411\u0435\u043b\u0433\u0438',
 u'bf': u'Burkina Faso',
 u'bg': u'\u0411\u043e\u043b\u0433\u0430\u0440',
 u'bh': u'\u0411\u0430\u0445\u0440\u044d\u0439\u043d',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Bermuda',
 u'bn': u'\u0411\u0440\u0443\u043d\u044d\u0439 \u0414\u0440\u0430\u0441\u0443\u043b\u0430\u043c',
 u'bo': u'\u0411\u043e\u043b\u0438\u0438\u0432',
 u'br': u'\u0411\u0440\u0430\u0437\u0438\u043b\u044c',
 u'bs': u'\u0411\u0430\u0445\u0430\u043c\u0430',
 u'bt': u'\u0411\u0443\u0442\u0430\u043d',
 u'bv': u'Bouvet Island',
 u'bw': u'\u0411\u043e\u0442\u0441\u0432\u0430\u043d\u0430',
 u'by': u'\u0411\u0435\u043b\u0430\u0440\u0443\u0441',
 u'bz': u'\u0411\u0435\u043b\u0438\u0437',
 u'ca': u'\u041a\u0430\u043d\u0430\u0434',
 u'cc': u'Cocos (Keeling) Islands',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Central African Republic',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'\u0428\u0432\u0435\u0439\u0446\u0430\u0440\u044c',
 u'ci': u'Ivory Coast',
 u'ck': u'Cook Islands',
 u'cl': u'\u0427\u0438\u043b',
 u'cm': u'\u041a\u0430\u043c\u0435\u0440\u0443\u043d',
 u'cn': u'\u0425\u044f\u0442\u0430\u0434',
 u'co': u'\u041a\u043e\u043b\u0443\u043c\u0431',
 u'cr': u'\u041a\u043e\u0441\u0442\u0430 \u0440\u0438\u043a\u0430',
 u'cu': u'\u041a\u0443\u0431\u0430',
 u'cv': u'Cape Verde',
 u'cx': u'Christmas Island',
 u'cy': u'Cyprus',
 u'cz': u'\u0427\u0435\u0445',
 u'de': u'\u0413\u0435\u0440\u043c\u0430\u043d',
 u'dj': u'Djibouti',
 u'dk': u'\u0414\u0430\u043d\u0438',
 u'dm': u'Dominica',
 u'do': u'\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d\u044b \u043d\u044d\u0433\u0434\u0441\u044d\u043d \u0430\u0440\u0434',
 u'dz': u'\u0410\u043b\u0436\u0435\u0440',
 u'ec': u'\u042d\u043a\u0443\u0430\u0434\u043e\u0440',
 u'ee': u'Estonia',
 u'eg': u'\u0415\u0433\u0438\u043f\u0442',
 u'eh': u'Western Sahara',
 u'er': u'Eritrea',
 u'es': u'\u0418\u0441\u043f\u0430\u043d',
 u'et': u'Ethiopia',
 u'fi': u'\u0424\u0438\u043d\u043b\u0430\u043d\u0434',
 u'fj': u'Fiji',
 u'fk': u'Falkland Islands (Malvinas)',
 u'fm': u'Micronesia',
 u'fo': u'Faroe Islands',
 u'fr': u'\u0424\u0440\u0430\u043d\u0446',
 u'ga': u'Gabon',
 u'gb': u'\u0410\u043d\u0433\u043b\u0438',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'French Guiana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Greenland',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Equatorial Guinea',
 u'gr': u'\u0413\u0440\u0435\u043a',
 u'gs': u'South Georgia and the South Sandwich Islands',
 u'gt': u'\u0413\u0443\u0430\u0442\u044d\u043c\u044d\u043b\u0430',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'\u0413\u043e\u043d\u0433 \u041a\u043e\u043d\u0433',
 u'hm': u'Heard Island and McDonald Islands',
 u'hn': u'\u0413\u043e\u043d\u0434\u0443\u0440',
 u'hr': u'\u041a\u0440\u043e\u0430\u0446\u0438',
 u'ht': u'Haiti',
 u'hu': u'\u0423\u043d\u0433\u0430\u0440',
 u'id': u'Indonesia',
 u'ie': u'\u0418\u0440\u043b\u0430\u043d\u0434',
 u'il': u'\u0418\u0437\u0440\u0430\u0439\u043b\u044c',
 u'im': u'Isle of Man',
 u'in': u'\u042d\u043d\u044d\u0442\u0445\u044d\u0433',
 u'io': u'British Indian Ocean Territory',
 u'iq': u'\u0418\u0440\u0430\u043a',
 u'ir': u'\u0418\u0440\u0430\u043d',
 u'is': u'Iceland',
 u'it': u'\u0418\u0442\u0430\u043b',
 u'je': u'Jersey',
 u'jm': u'\u0416\u0430\u043c\u0430\u0439\u043a',
 u'jo': u'\u0401\u0440\u0434\u0430\u043d',
 u'jp': u'\u042f\u043f\u043e\u043d',
 u'ke': u'Kenya',
 u'kg': u'Kyrgyzstan',
 u'kh': u'Cambodia',
 u'ki': u'Kiribati',
 u'km': u'Comoros',
 u'kn': u'Saint Kitts and Nevis',
 u'kp': u'\u0425\u043e\u0439\u0434 \u0441\u043e\u043b\u043e\u043d\u0433\u043e\u0441',
 u'kr': u'\u04e8\u043c\u043d\u04e9\u0434 \u0421\u043e\u043b\u043e\u043d\u0433\u043e\u0441',
 u'kw': u'\u041a\u0443\u0432\u044d\u0439\u0442',
 u'ky': u'Cayman Islands',
 u'kz': u'Kazakhstan',
 u'la': u'Laos',
 u'lb': u'\u041b\u044d\u0431\u0430\u043d',
 u'lc': u'Saint Lucia',
 u'li': u'\u041b\u0438\u0445\u0442\u044d\u043d\u0448\u0442\u0430\u0439\u043d',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'\u041b\u0438\u0442\u0430\u0443\u0430\u043d',
 u'lu': u'\u041b\u0443\u043a\u0441\u044d\u043d\u0431\u0443\u0440\u0433',
 u'lv': u'Latvia',
 u'ly': u'\u041b\u0438\u0431\u0438\u0430',
 u'ma': u'\u041c\u043e\u0440\u0440\u043e\u043a',
 u'mc': u'\u041c\u043e\u043d\u0430\u043a',
 u'md': u'Moldova',
 u'me': u'\u041c\u043e\u043d\u0442\u044d\u043d\u0435\u0433\u0440\u043e',
 u'mf': u'\u0421\u044d\u0439\u043d \u041c\u0430\u0440\u0442\u0438\u043d',
 u'mg': u'Madagascar',
 u'mh': u'Marshall Islands',
 u'mk': u'Macedonia, F.Y.R. of',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'\u041c\u043e\u043d\u0433\u043e\u043b',
 u'mo': u'\u041c\u0430\u043a\u0430\u043e',
 u'mp': u'Northern Mariana Islands',
 u'mq': u'Martinique',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Maldives',
 u'mw': u'Malawi',
 u'mx': u'\u041c\u0435\u043a\u0441\u0438\u043e',
 u'my': u'\u041c\u0430\u043b\u0430\u0439\u0437',
 u'mz': u'Mozambique',
 u'na': u'Namibia',
 u'nc': u'New Caledonia',
 u'ne': u'Niger',
 u'nf': u'Norfolk Island',
 u'ng': u'Nigeria',
 u'ni': u'\u041d\u0438\u043a\u0430\u0440\u0430\u0433\u0443\u0430\u0433',
 u'nl': u'\u0413\u043e\u043b\u043b\u0430\u043d\u0434',
 u'no': u'\u041d\u043e\u0440\u0432\u0435\u0433',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'\u0428\u0438\u043d\u044d \u0437\u0435\u043b\u0430\u043d\u0434',
 u'om': u'\u041e\u043c\u0430\u043d',
 u'pa': u'\u041f\u0430\u043d\u0430\u043c',
 u'pe': u'\u041f\u0435\u0440\u0443',
 u'pf': u'French Polynesia',
 u'pg': u'Papua New Guinea',
 u'ph': u'\u0424\u0438\u043b\u0438\u043f\u0438\u043d',
 u'pk': u'\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u043d',
 u'pl': u'\u041f\u043e\u043b\u044c\u0448',
 u'pm': u'Saint Pierre and Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'\u041f\u0443\u044d\u0440\u0442\u043e \u0440\u0438\u043a\u043e',
 u'ps': u'Occupied Palestinian Territory',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'\u041f\u0430\u0440\u0430\u0433\u0443\u0430\u0439',
 u'qa': u'\u041a\u0430\u0442\u0430\u0440',
 u're': u'Reunion',
 u'ro': u'\u0420\u0443\u043c\u0438\u043d',
 u'rs': u'\u0421\u0435\u0440\u0431',
 u'ru': u'\u041e\u0440\u043e\u0441',
 u'rw': u'Rwanda',
 u'sa': u'\u0421\u0430\u0443\u0434\u044b\u043d \u0410\u0440\u0430\u0431',
 u'sb': u'\u0421\u043e\u043b\u043e\u043c\u043e\u043d \u0430\u0440\u0430\u043b',
 u'sc': u'Seychelles',
 u'sd': u'\u0421\u0443\u0434\u0430\u043d',
 u'se': u'\u0428\u0432\u0435\u0434\u044c',
 u'sg': u'\u0421\u0438\u043d\u0433\u0430\u043f\u0443\u0440',
 u'sh': u'Saint Helena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard and Jan Mayen',
 u'sk': u'\u0421\u043b\u043e\u0432\u0430\u043a',
 u'sl': u'Sierra Leone',
 u'sm': u'\u0421\u0430\u043d \u041c\u0430\u0440\u0438\u043d\u043e',
 u'sn': u'\u0421\u0435\u043d\u0435\u0433\u0430\u043b',
 u'so': u'Somalia',
 u'sr': u'Suriname',
 u'st': u'Sao Tome and Principe',
 u'sv': u'\u042d\u043b \u0441\u0430\u043b\u044c\u0432\u0430\u0434\u043e\u0440',
 u'sy': u'\u0421\u0438\u0440\u044c',
 u'sz': u'Swaziland',
 u'tc': u'Turks and Caicos Islands',
 u'td': u'Chad',
 u'tf': u'French Southern Territories',
 u'tg': u'Togo',
 u'th': u'\u0422\u0430\u0439\u043b\u0430\u043d\u0434',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'\u0422\u0443\u043d\u0435\u0441',
 u'to': u'Tonga',
 u'tr': u'\u0422\u0443\u0440\u043a',
 u'tt': u'\u0422\u0440\u0438\u043d\u0438\u0434\u0430\u0434',
 u'tv': u'Tuvalu',
 u'tw': u'\u0422\u0430\u0439\u0432\u0430\u043d\u044c',
 u'tz': u'Tanzania',
 u'ua': u'\u0423\u043a\u0440\u0430\u0439\u043d',
 u'ug': u'Uganda',
 u'um': u'United States Minor Outlying Islands',
 u'us': u'\u0410\u043c\u0435\u0440\u0438\u043a',
 u'uy': u'\u0423\u0440\u0443\u0433\u0443\u0430\u0439',
 u'uz': u'Uzbekistan',
 u'va': u'Vatican City',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'\u0412\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u044c',
 u'vg': u'British Virgin Islands',
 u'vi': u'U.S. Virgin Islands',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis and Futuna',
 u'ws': u'Samoa',
 u'ye': u'\u0415\u043c\u0435\u043d',
 u'yt': u'Mayotte',
 u'za': u'\u04e8\u043c\u043d\u04e9\u0434 \u0430\u0444\u0440\u0438\u043a',
 u'zm': u'Zambia',
 u'zw': u'\u0417\u0438\u043c\u0431\u0430\u0431'}
